@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.034-1-g5d730f7
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.035-7-ge677b4b
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
 # vim: set ts=8 sw=4 tw=78 et :
-$Dist::Zilla::Plugin::PromptIfStale::VERSION = '0.035';
+$Dist::Zilla::Plugin::PromptIfStale::VERSION = '0.036';
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
     'Dist::Zilla::Role::AfterBuild',
@@ -205,9 +205,8 @@ sub stale_modules
 
             if (Module::CoreList::is_core($module) and not $self->_is_duallifed($module))
             {
-                $self->log_debug([ 'core module %s is indexed at version %s but you only have %s installed. You need to use update your perl to get the latest version.',
-                    $module, $indexed_version, $local_version,
-                ]);
+                $self->log_debug([ 'core module %s is indexed at version %s but you only have %s installed. You need to update your perl to get the latest version.',
+                    $module, sub { ($indexed_version // 'undef') . '' }, sub { ($local_version // 'undef') . '' } ]);
             }
             else
             {
@@ -355,8 +354,8 @@ sub _is_duallifed
     my $payload = YAML::Tiny->read_string($data);
 
     $self->log('invalid payload returned?'), return undef unless $payload;
-    $self->log_debug([ '%s not indexed', $module ]), return undef if not defined $payload->[0]{dist_name};
-    CPAN::DistnameInfo->new($payload->[0]{dist_name})->dist ne 'perl';
+    $self->log_debug([ '%s not indexed', $module ]), return undef if not defined $payload->[0]{distfile};
+    return CPAN::DistnameInfo->new($payload->[0]{distfile})->dist ne 'perl';
 }
 
 my $packages;
@@ -448,7 +447,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.035
+version 0.036
 
 =head1 SYNOPSIS
 
